@@ -3,13 +3,20 @@
 
 #include <iostream>
 
+#include <GLFW/glfw3.h>
+
 #include <glbinding/gl/gl.h>
 
-#include <glbinding/AbstractFunction.h> 
-#include <glbinding/callbacks.h>
+#include <glbinding/AbstractFunction.h>
+
+#include <glbinding-aux/types_to_string.h>
 
 #include <glbinding/Binding.h>
 
+#include <glbinding/CallbackMask.h>
+
+#include <glbinding/FunctionCall.h>
+
 
 using namespace gl;
 
@@ -21,7 +28,9 @@ namespace
 
 void glbinding_init()
 {
-    glbinding::Binding::initialize(false);
+    glbinding::Binding::initialize([](const char * name) {
+        return glfwGetProcAddress(name);
+    }, false);
 }
 
 
@@ -35,9 +44,9 @@ void glbinding_error(bool enable)
 {
     if (enable)
     {
-        glbinding::setCallbackMaskExcept(glbinding::CallbackMask::After, { "glGetError" });
+        glbinding::Binding::setCallbackMaskExcept(glbinding::CallbackMask::After, { "glGetError" });
 
-        glbinding::setAfterCallback([](const glbinding::FunctionCall &)
+        glbinding::Binding::setAfterCallback([](const glbinding::FunctionCall &)
         {
             gl::GLenum error = gl::glGetError();
             if (error != gl::GL_NO_ERROR)
@@ -45,5 +54,5 @@ void glbinding_error(bool enable)
         });
     }
     else
-        glbinding::setCallbackMask(glbinding::CallbackMask::None);
+        glbinding::Binding::setCallbackMask(glbinding::CallbackMask::None);
 }
