@@ -1,8 +1,9 @@
 
 #include "Painter.h"
 
-#include <glbinding/Binding.h>
-#include <glbinding/ContextInfo.h>
+#include <glbinding/glbinding.h>
+
+#include <glbinding-aux/ContextInfo.h>
 
 #include "../cubescape/CubeScape.h"
 
@@ -18,12 +19,12 @@ Painter::~Painter()
     delete m_cubescape;
 }
 
-void Painter::initialize()
+void Painter::initialize(ProcAddressGetter procAddressCallback)
 {
     if (m_initialized)
         return;
 
-    glbinding::Binding::initialize(false); // only resolve functions that are actually used (lazy)
+    glbinding::initialize(procAddressCallback, false); // only resolve functions that are actually used (lazy)
 
     m_cubescape = new CubeScape();
 
