@@ -2,6 +2,9 @@
 #pragma once
 
 
+#include <functional>
+
+
 class CubeScape;
 
 // wrapper for cubescape to avoid overlapping qopengl and glbinding includes
@@ -9,13 +12,16 @@ class CubeScape;
 // Note: Qt could use a NO_GL_FUNCTIONS define (similar to GLFW_INCLUDE_NONE), but for
 //       now the QOpenGLContext is tightly coupled with qopengl.h and QOpenGLFunctions.
 
+using ProcAddress = void(*)();
+using ProcAddressGetter = ProcAddress(*)(const char*);
+
 class Painter
 {
 public:
     Painter();
     ~Painter();
 
-    void initialize();
+    void initialize(ProcAddressGetter procAddressCallback);
 
     void resize(int width, int height);
     void draw();
