@@ -1,5 +1,7 @@
+
 #pragma once
 
+
 #include <glbinding/nogl.h>
 
 
@@ -7,7 +9,7 @@ namespace gl
 {
 
 
-enum class GLextension : int // GLextension is not a type introduced by OpenGL API so far
+enum class GLextension : int // GLextension is not a type introduced by GL API so far
 {
     UNKNOWN = -1,
     GL_3DFX_multisample,
@@ -18,7 +20,11 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_AMD_debug_output,
     GL_AMD_depth_clamp_separate,
     GL_AMD_draw_buffers_blend,
+    GL_AMD_framebuffer_multisample_advanced,
+    GL_AMD_framebuffer_sample_positions,
     GL_AMD_gcn_shader,
+    GL_AMD_gpu_shader_half_float,
+    GL_AMD_gpu_shader_int16,
     GL_AMD_gpu_shader_int64,
     GL_AMD_interleaved_elements,
     GL_AMD_multi_draw_indirect,
@@ -30,11 +36,15 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_AMD_sample_positions,
     GL_AMD_seamless_cubemap_per_texture,
     GL_AMD_shader_atomic_counter_ops,
+    GL_AMD_shader_ballot,
     GL_AMD_shader_explicit_vertex_parameter,
+    GL_AMD_shader_gpu_shader_half_float_fetch,
+    GL_AMD_shader_image_load_store_lod,
     GL_AMD_shader_stencil_export,
     GL_AMD_shader_trinary_minmax,
     GL_AMD_sparse_texture,
     GL_AMD_stencil_operation_extended,
+    GL_AMD_texture_gather_bias_lod,
     GL_AMD_texture_texture4,
     GL_AMD_transform_feedback3_lines_triangles,
     GL_AMD_transform_feedback4,
@@ -57,10 +67,6 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_APPLE_vertex_array_range,
     GL_APPLE_vertex_program_evaluators,
     GL_APPLE_ycbcr_422,
-    GL_ARB_ES2_compatibility,
-    GL_ARB_ES3_1_compatibility,
-    GL_ARB_ES3_2_compatibility,
-    GL_ARB_ES3_compatibility,
     GL_ARB_arrays_of_arrays,
     GL_ARB_base_instance,
     GL_ARB_bindless_texture,
@@ -92,6 +98,10 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_ARB_draw_indirect,
     GL_ARB_draw_instanced,
     GL_ARB_enhanced_layouts,
+    GL_ARB_ES2_compatibility,
+    GL_ARB_ES3_1_compatibility,
+    GL_ARB_ES3_2_compatibility,
+    GL_ARB_ES3_compatibility,
     GL_ARB_explicit_attrib_location,
     GL_ARB_explicit_uniform_location,
     GL_ARB_fragment_coord_conventions,
@@ -106,6 +116,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_ARB_geometry_shader4,
     GL_ARB_get_program_binary,
     GL_ARB_get_texture_sub_image,
+    GL_ARB_gl_spirv,
     GL_ARB_gpu_shader5,
     GL_ARB_gpu_shader_fp64,
     GL_ARB_gpu_shader_int64,
@@ -131,6 +142,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_ARB_pixel_buffer_object,
     GL_ARB_point_parameters,
     GL_ARB_point_sprite,
+    GL_ARB_polygon_offset_clamp,
     GL_ARB_post_depth_coverage,
     GL_ARB_program_interface_query,
     GL_ARB_provoking_vertex,
@@ -171,6 +183,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_ARB_sparse_texture,
     GL_ARB_sparse_texture2,
     GL_ARB_sparse_texture_clamp,
+    GL_ARB_spirv_extensions,
     GL_ARB_stencil_texturing,
     GL_ARB_sync,
     GL_ARB_tessellation_shader,
@@ -188,6 +201,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_ARB_texture_env_combine,
     GL_ARB_texture_env_crossbar,
     GL_ARB_texture_env_dot3,
+    GL_ARB_texture_filter_anisotropic,
     GL_ARB_texture_filter_minmax,
     GL_ARB_texture_float,
     GL_ARB_texture_gather,
@@ -265,6 +279,9 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_draw_buffers2,
     GL_EXT_draw_instanced,
     GL_EXT_draw_range_elements,
+    GL_EXT_EGL_image_storage,
+    GL_EXT_EGL_sync,
+    GL_EXT_external_buffer,
     GL_EXT_fog_coord,
     GL_EXT_framebuffer_blit,
     GL_EXT_framebuffer_multisample,
@@ -280,9 +297,15 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_index_material,
     GL_EXT_index_texture,
     GL_EXT_light_texture,
+    GL_EXT_memory_object,
+    GL_EXT_memory_object_fd,
+    GL_EXT_memory_object_win32,
     GL_EXT_misc_attribute,
     GL_EXT_multi_draw_arrays,
     GL_EXT_multisample,
+    GL_EXT_multiview_tessellation_geometry_shader,
+    GL_EXT_multiview_texture_multisample,
+    GL_EXT_multiview_timer_query,
     GL_EXT_packed_depth_stencil,
     GL_EXT_packed_float,
     GL_EXT_packed_pixels,
@@ -298,11 +321,17 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_raster_multisample,
     GL_EXT_rescale_normal,
     GL_EXT_secondary_color,
+    GL_EXT_semaphore,
+    GL_EXT_semaphore_fd,
+    GL_EXT_semaphore_win32,
     GL_EXT_separate_shader_objects,
     GL_EXT_separate_specular_color,
+    GL_EXT_shader_framebuffer_fetch,
+    GL_EXT_shader_framebuffer_fetch_non_coherent,
     GL_EXT_shader_image_load_formatted,
     GL_EXT_shader_image_load_store,
     GL_EXT_shader_integer_mix,
+    GL_EXT_shader_samples_identical,
     GL_EXT_shadow_funcs,
     GL_EXT_shared_texture_palette,
     GL_EXT_sparse_texture2,
@@ -328,10 +357,14 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_texture_mirror_clamp,
     GL_EXT_texture_object,
     GL_EXT_texture_perturb_normal,
-    GL_EXT_texture_sRGB,
-    GL_EXT_texture_sRGB_decode,
+    GL_EXT_texture_shadow_lod,
     GL_EXT_texture_shared_exponent,
     GL_EXT_texture_snorm,
+    GL_EXT_texture_sRGB,
+    GL_EXT_texture_sRGB_decode,
+    GL_EXT_texture_sRGB_R8,
+    GL_EXT_texture_sRGB_RG8,
+    GL_EXT_texture_storage,
     GL_EXT_texture_swizzle,
     GL_EXT_timer_query,
     GL_EXT_transform_feedback,
@@ -340,6 +373,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_vertex_attrib_64bit,
     GL_EXT_vertex_shader,
     GL_EXT_vertex_weighting,
+    GL_EXT_win32_keyed_mutex,
     GL_EXT_window_rectangles,
     GL_EXT_x11_sync_object,
     GL_GREMEDY_frame_terminator,
@@ -357,6 +391,8 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_INGR_blend_func_separate,
     GL_INGR_color_clamp,
     GL_INGR_interlace_read,
+    GL_INTEL_blackhole_render,
+    GL_INTEL_conservative_rasterization,
     GL_INTEL_fragment_shader_ordering,
     GL_INTEL_framebuffer_CMAA,
     GL_INTEL_map_texture,
@@ -367,37 +403,49 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_KHR_context_flush_control,
     GL_KHR_debug,
     GL_KHR_no_error,
+    GL_KHR_parallel_shader_compile,
     GL_KHR_robust_buffer_access_behavior,
     GL_KHR_robustness,
+    GL_KHR_shader_subgroup,
     GL_KHR_texture_compression_astc_hdr,
     GL_KHR_texture_compression_astc_ldr,
     GL_KHR_texture_compression_astc_sliced_3d,
-    GL_MESAX_texture_stack,
+    GL_MESA_framebuffer_flip_x,
+    GL_MESA_framebuffer_flip_y,
+    GL_MESA_framebuffer_swap_xy,
     GL_MESA_pack_invert,
+    GL_MESA_program_binary_formats,
     GL_MESA_resize_buffers,
+    GL_MESA_shader_integer_functions,
+    GL_MESA_tile_raster_order,
     GL_MESA_window_pos,
     GL_MESA_ycbcr_texture,
-    GL_NVX_conditional_render,
-    GL_NVX_gpu_memory_info,
+    GL_MESAX_texture_stack,
+    GL_NV_alpha_to_coverage_dither_control,
     GL_NV_bindless_multi_draw_indirect,
     GL_NV_bindless_multi_draw_indirect_count,
     GL_NV_bindless_texture,
     GL_NV_blend_equation_advanced,
     GL_NV_blend_equation_advanced_coherent,
+    GL_NV_blend_minmax_factor,
     GL_NV_blend_square,
     GL_NV_clip_space_w_scaling,
     GL_NV_command_list,
     GL_NV_compute_program5,
+    GL_NV_compute_shader_derivatives,
     GL_NV_conditional_render,
     GL_NV_conservative_raster,
     GL_NV_conservative_raster_dilate,
+    GL_NV_conservative_raster_pre_snap,
     GL_NV_conservative_raster_pre_snap_triangles,
+    GL_NV_conservative_raster_underestimation,
     GL_NV_copy_depth_to_color,
     GL_NV_copy_image,
     GL_NV_deep_texture3D,
     GL_NV_depth_buffer_float,
     GL_NV_depth_clamp,
     GL_NV_draw_texture,
+    GL_NV_draw_vulkan_image,
     GL_NV_evaluators,
     GL_NV_explicit_multisample,
     GL_NV_fence,
@@ -409,12 +457,14 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_fragment_program2,
     GL_NV_fragment_program4,
     GL_NV_fragment_program_option,
+    GL_NV_fragment_shader_barycentric,
     GL_NV_fragment_shader_interlock,
     GL_NV_framebuffer_mixed_samples,
     GL_NV_framebuffer_multisample_coverage,
     GL_NV_geometry_program4,
     GL_NV_geometry_shader4,
     GL_NV_geometry_shader_passthrough,
+    GL_NV_gpu_multicast,
     GL_NV_gpu_program4,
     GL_NV_gpu_program5,
     GL_NV_gpu_program5_mem_extended,
@@ -422,6 +472,9 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_half_float,
     GL_NV_internalformat_sample_query,
     GL_NV_light_max_exponent,
+    GL_NV_memory_attachment,
+    GL_NV_memory_object_sparse,
+    GL_NV_mesh_shader,
     GL_NV_multisample_coverage,
     GL_NV_multisample_filter_hint,
     GL_NV_occlusion_query,
@@ -434,11 +487,16 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_point_sprite,
     GL_NV_present_video,
     GL_NV_primitive_restart,
+    GL_NV_primitive_shading_rate,
+    GL_NV_query_resource,
+    GL_NV_query_resource_tag,
     GL_NV_register_combiners,
     GL_NV_register_combiners2,
+    GL_NV_representative_fragment_test,
     GL_NV_robustness_video_memory_purge,
     GL_NV_sample_locations,
     GL_NV_sample_mask_override_coverage,
+    GL_NV_scissor_exclusive,
     GL_NV_shader_atomic_counters,
     GL_NV_shader_atomic_float,
     GL_NV_shader_atomic_float64,
@@ -447,8 +505,11 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_shader_buffer_load,
     GL_NV_shader_buffer_store,
     GL_NV_shader_storage_buffer_object,
+    GL_NV_shader_subgroup_partitioned,
+    GL_NV_shader_texture_footprint,
     GL_NV_shader_thread_group,
     GL_NV_shader_thread_shuffle,
+    GL_NV_shading_rate_image,
     GL_NV_stereo_view_rendering,
     GL_NV_tessellation_program5,
     GL_NV_texgen_emboss,
@@ -459,13 +520,16 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_texture_expand_normal,
     GL_NV_texture_multisample,
     GL_NV_texture_rectangle,
+    GL_NV_texture_rectangle_compressed,
     GL_NV_texture_shader,
     GL_NV_texture_shader2,
     GL_NV_texture_shader3,
+    GL_NV_timeline_semaphore,
     GL_NV_transform_feedback,
     GL_NV_transform_feedback2,
     GL_NV_uniform_buffer_unified_memory,
     GL_NV_vdpau_interop,
+    GL_NV_vdpau_interop2,
     GL_NV_vertex_array_range,
     GL_NV_vertex_array_range2,
     GL_NV_vertex_attrib_integer_64bit,
@@ -479,6 +543,12 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_video_capture,
     GL_NV_viewport_array2,
     GL_NV_viewport_swizzle,
+    GL_NVX_blend_equation_advanced_multi_draw_buffers,
+    GL_NVX_conditional_render,
+    GL_NVX_gpu_memory_info,
+    GL_NVX_gpu_multicast2,
+    GL_NVX_linked_gpu_multicast,
+    GL_NVX_progress_fence,
     GL_OES_byte_coordinates,
     GL_OES_compressed_paletted_texture,
     GL_OES_fixed_point,
@@ -494,6 +564,9 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_PGI_vertex_hints,
     GL_REND_screen_coordinates,
     GL_S3_s3tc,
+    GL_SGI_color_matrix,
+    GL_SGI_color_table,
+    GL_SGI_texture_color_table,
     GL_SGIS_detail_texture,
     GL_SGIS_fog_function,
     GL_SGIS_generate_mipmap,
@@ -547,19 +620,17 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_SGIX_ycrcb,
     GL_SGIX_ycrcb_subsample,
     GL_SGIX_ycrcba,
-    GL_SGI_color_matrix,
-    GL_SGI_color_table,
-    GL_SGI_texture_color_table,
-    GL_SUNX_constant_data,
     GL_SUN_convolution_border_modes,
     GL_SUN_global_alpha,
     GL_SUN_mesh_array,
     GL_SUN_slice_accum,
     GL_SUN_triangle_list,
     GL_SUN_vertex,
+    GL_SUNX_constant_data,
     GL_WIN_phong_shading,
     GL_WIN_specular_fog
+    
 };
 
 
-} // namespace gl
+} // namespace gl
\ No newline at end of file
