@@ -1,6 +1,9 @@
+
 #pragma once
 
+
 #include <glbinding/nogl.h>
+
 #include <glbinding/gl/values.h>
 
 
@@ -8,9 +11,12 @@ namespace gl10ext
 {
 
 
+// import values to namespace
+using gl::GL_ALL_PIXELS_AMD;
 using gl::GL_INVALID_INDEX;
-
+using gl::GL_LUID_SIZE_EXT;
 using gl::GL_TIMEOUT_IGNORED;
+using gl::GL_UUID_SIZE_EXT;
 
 
-} // namespace gl10ext
+} // namespace gl10ext
\ No newline at end of file
