@@ -1,5 +1,7 @@
+
 #pragma once
 
+
 #include <glbinding/nogl.h>
 
 #include <glbinding/gl/boolean.h>
@@ -9,10 +11,13 @@ namespace gl13
 {
 
 
-// import booleans to namespace
+// use boolean type
+using gl::GLboolean;
 
+
+// import booleans to namespace
 using gl::GL_FALSE;
 using gl::GL_TRUE;
 
 
-} // namespace gl13
+} // namespace gl13
\ No newline at end of file
