@@ -1,5 +1,7 @@
+
 #pragma once
 
+
 #include <glbinding/nogl.h>
 #include <glbinding/gl/functions.h>
 
@@ -7,7 +9,7 @@
 namespace gl44core
 {
 
-
+// import functions
 using gl::glActiveShaderProgram;
 using gl::glActiveTexture;
 using gl::glAttachShader;
@@ -38,13 +40,13 @@ using gl::glBindVertexBuffer;
 using gl::glBindVertexBuffers;
 using gl::glBlendColor;
 using gl::glBlendEquation;
+using gl::glBlendEquationi;
 using gl::glBlendEquationSeparate;
 using gl::glBlendEquationSeparatei;
-using gl::glBlendEquationi;
 using gl::glBlendFunc;
+using gl::glBlendFunci;
 using gl::glBlendFuncSeparate;
 using gl::glBlendFuncSeparatei;
-using gl::glBlendFunci;
 using gl::glBlitFramebuffer;
 using gl::glBufferData;
 using gl::glBufferStorage;
@@ -53,10 +55,10 @@ using gl::glCheckFramebufferStatus;
 using gl::glClampColor;
 using gl::glClear;
 using gl::glClearBufferData;
-using gl::glClearBufferSubData;
 using gl::glClearBufferfi;
 using gl::glClearBufferfv;
 using gl::glClearBufferiv;
+using gl::glClearBufferSubData;
 using gl::glClearBufferuiv;
 using gl::glClearColor;
 using gl::glClearDepth;
@@ -108,12 +110,12 @@ using gl::glDepthFunc;
 using gl::glDepthMask;
 using gl::glDepthRange;
 using gl::glDepthRangeArrayv;
-using gl::glDepthRangeIndexed;
 using gl::glDepthRangef;
+using gl::glDepthRangeIndexed;
 using gl::glDetachShader;
 using gl::glDisable;
-using gl::glDisableVertexAttribArray;
 using gl::glDisablei;
+using gl::glDisableVertexAttribArray;
 using gl::glDispatchCompute;
 using gl::glDispatchComputeIndirect;
 using gl::glDrawArrays;
@@ -136,8 +138,8 @@ using gl::glDrawTransformFeedbackInstanced;
 using gl::glDrawTransformFeedbackStream;
 using gl::glDrawTransformFeedbackStreamInstanced;
 using gl::glEnable;
-using gl::glEnableVertexAttribArray;
 using gl::glEnablei;
+using gl::glEnableVertexAttribArray;
 using gl::glEndConditionalRender;
 using gl::glEndQuery;
 using gl::glEndQueryIndexed;
@@ -155,6 +157,7 @@ using gl::glFramebufferTexture3D;
 using gl::glFramebufferTextureLayer;
 using gl::glFrontFace;
 using gl::glGenBuffers;
+using gl::glGenerateMipmap;
 using gl::glGenFramebuffers;
 using gl::glGenProgramPipelines;
 using gl::glGenQueries;
@@ -163,15 +166,14 @@ using gl::glGenSamplers;
 using gl::glGenTextures;
 using gl::glGenTransformFeedbacks;
 using gl::glGenVertexArrays;
-using gl::glGenerateMipmap;
 using gl::glGetActiveAtomicCounterBufferiv;
 using gl::glGetActiveAttrib;
 using gl::glGetActiveSubroutineName;
-using gl::glGetActiveSubroutineUniformName;
 using gl::glGetActiveSubroutineUniformiv;
+using gl::glGetActiveSubroutineUniformName;
 using gl::glGetActiveUniform;
-using gl::glGetActiveUniformBlockName;
 using gl::glGetActiveUniformBlockiv;
+using gl::glGetActiveUniformBlockName;
 using gl::glGetActiveUniformName;
 using gl::glGetActiveUniformsiv;
 using gl::glGetAttachedShaders;
@@ -202,33 +204,34 @@ using gl::glGetInternalformativ;
 using gl::glGetMultisamplefv;
 using gl::glGetObjectLabel;
 using gl::glGetObjectPtrLabel;
+using gl::glGetPointerv;
 using gl::glGetProgramBinary;
 using gl::glGetProgramInfoLog;
 using gl::glGetProgramInterfaceiv;
+using gl::glGetProgramiv;
 using gl::glGetProgramPipelineInfoLog;
 using gl::glGetProgramPipelineiv;
 using gl::glGetProgramResourceIndex;
+using gl::glGetProgramResourceiv;
 using gl::glGetProgramResourceLocation;
 using gl::glGetProgramResourceLocationIndex;
 using gl::glGetProgramResourceName;
-using gl::glGetProgramResourceiv;
 using gl::glGetProgramStageiv;
-using gl::glGetProgramiv;
 using gl::glGetQueryIndexediv;
+using gl::glGetQueryiv;
 using gl::glGetQueryObjecti64v;
 using gl::glGetQueryObjectiv;
 using gl::glGetQueryObjectui64v;
 using gl::glGetQueryObjectuiv;
-using gl::glGetQueryiv;
 using gl::glGetRenderbufferParameteriv;
+using gl::glGetSamplerParameterfv;
 using gl::glGetSamplerParameterIiv;
 using gl::glGetSamplerParameterIuiv;
-using gl::glGetSamplerParameterfv;
 using gl::glGetSamplerParameteriv;
 using gl::glGetShaderInfoLog;
+using gl::glGetShaderiv;
 using gl::glGetShaderPrecisionFormat;
 using gl::glGetShaderSource;
-using gl::glGetShaderiv;
 using gl::glGetString;
 using gl::glGetStringi;
 using gl::glGetSubroutineIndex;
@@ -237,26 +240,26 @@ using gl::glGetSynciv;
 using gl::glGetTexImage;
 using gl::glGetTexLevelParameterfv;
 using gl::glGetTexLevelParameteriv;
+using gl::glGetTexParameterfv;
 using gl::glGetTexParameterIiv;
 using gl::glGetTexParameterIuiv;
-using gl::glGetTexParameterfv;
 using gl::glGetTexParameteriv;
 using gl::glGetTransformFeedbackVarying;
 using gl::glGetUniformBlockIndex;
-using gl::glGetUniformIndices;
-using gl::glGetUniformLocation;
-using gl::glGetUniformSubroutineuiv;
 using gl::glGetUniformdv;
 using gl::glGetUniformfv;
+using gl::glGetUniformIndices;
 using gl::glGetUniformiv;
+using gl::glGetUniformLocation;
+using gl::glGetUniformSubroutineuiv;
 using gl::glGetUniformuiv;
-using gl::glGetVertexAttribIiv;
-using gl::glGetVertexAttribIuiv;
-using gl::glGetVertexAttribLdv;
-using gl::glGetVertexAttribPointerv;
 using gl::glGetVertexAttribdv;
 using gl::glGetVertexAttribfv;
+using gl::glGetVertexAttribIiv;
+using gl::glGetVertexAttribIuiv;
 using gl::glGetVertexAttribiv;
+using gl::glGetVertexAttribLdv;
+using gl::glGetVertexAttribPointerv;
 using gl::glHint;
 using gl::glInvalidateBufferData;
 using gl::glInvalidateBufferSubData;
@@ -379,11 +382,11 @@ using gl::glRenderbufferStorageMultisample;
 using gl::glResumeTransformFeedback;
 using gl::glSampleCoverage;
 using gl::glSampleMaski;
-using gl::glSamplerParameterIiv;
-using gl::glSamplerParameterIuiv;
 using gl::glSamplerParameterf;
 using gl::glSamplerParameterfv;
 using gl::glSamplerParameteri;
+using gl::glSamplerParameterIiv;
+using gl::glSamplerParameterIuiv;
 using gl::glSamplerParameteriv;
 using gl::glScissor;
 using gl::glScissorArrayv;
@@ -415,11 +418,11 @@ using gl::glTexImage2D;
 using gl::glTexImage2DMultisample;
 using gl::glTexImage3D;
 using gl::glTexImage3DMultisample;
-using gl::glTexParameterIiv;
-using gl::glTexParameterIuiv;
 using gl::glTexParameterf;
 using gl::glTexParameterfv;
 using gl::glTexParameteri;
+using gl::glTexParameterIiv;
+using gl::glTexParameterIuiv;
 using gl::glTexParameteriv;
 using gl::glTexStorage1D;
 using gl::glTexStorage2D;
@@ -506,6 +509,12 @@ using gl::glVertexAttrib3f;
 using gl::glVertexAttrib3fv;
 using gl::glVertexAttrib3s;
 using gl::glVertexAttrib3sv;
+using gl::glVertexAttrib4bv;
+using gl::glVertexAttrib4d;
+using gl::glVertexAttrib4dv;
+using gl::glVertexAttrib4f;
+using gl::glVertexAttrib4fv;
+using gl::glVertexAttrib4iv;
 using gl::glVertexAttrib4Nbv;
 using gl::glVertexAttrib4Niv;
 using gl::glVertexAttrib4Nsv;
@@ -513,12 +522,6 @@ using gl::glVertexAttrib4Nub;
 using gl::glVertexAttrib4Nubv;
 using gl::glVertexAttrib4Nuiv;
 using gl::glVertexAttrib4Nusv;
-using gl::glVertexAttrib4bv;
-using gl::glVertexAttrib4d;
-using gl::glVertexAttrib4dv;
-using gl::glVertexAttrib4f;
-using gl::glVertexAttrib4fv;
-using gl::glVertexAttrib4iv;
 using gl::glVertexAttrib4s;
 using gl::glVertexAttrib4sv;
 using gl::glVertexAttrib4ubv;
@@ -581,5 +584,4 @@ using gl::glViewportIndexedf;
 using gl::glViewportIndexedfv;
 using gl::glWaitSync;
 
-
-} // namespace gl44core
+} // namespace gl44core
\ No newline at end of file
