@@ -1,5 +1,7 @@
+
 #pragma once
 
+
 #include <glbinding/nogl.h>
 #include <glbinding/gl/functions.h>
 
@@ -7,9 +9,11 @@
 namespace gl45ext
 {
 
-
+// import functions
 using gl::glAccumxOES;
+using gl::glAcquireKeyedMutexWin32EXT;
 using gl::glActiveProgramEXT;
+using gl::glActiveShaderProgramEXT;
 using gl::glActiveStencilFaceEXT;
 using gl::glActiveTextureARB;
 using gl::glActiveVaryingNV;
@@ -17,12 +21,15 @@ using gl::glAlphaFragmentOp1ATI;
 using gl::glAlphaFragmentOp2ATI;
 using gl::glAlphaFragmentOp3ATI;
 using gl::glAlphaFuncxOES;
+using gl::glAlphaToCoverageDitherControlNV;
 using gl::glApplyFramebufferAttachmentCMAAINTEL;
 using gl::glApplyTextureEXT;
 using gl::glAreProgramsResidentNV;
 using gl::glAreTexturesResidentEXT;
 using gl::glArrayElementEXT;
 using gl::glArrayObjectATI;
+using gl::glAsyncCopyBufferSubDataNVX;
+using gl::glAsyncCopyImageSubDataNVX;
 using gl::glAsyncMarkerSGIX;
 using gl::glAttachObjectARB;
 using gl::glBeginConditionalRenderNV;
@@ -54,7 +61,9 @@ using gl::glBindMultiTextureEXT;
 using gl::glBindParameterEXT;
 using gl::glBindProgramARB;
 using gl::glBindProgramNV;
+using gl::glBindProgramPipelineEXT;
 using gl::glBindRenderbufferEXT;
+using gl::glBindShadingRateImageNV;
 using gl::glBindTexGenParameterEXT;
 using gl::glBindTextureEXT;
 using gl::glBindTextureUnitParameterEXT;
@@ -80,23 +89,27 @@ using gl::glBlendBarrierNV;
 using gl::glBlendColorEXT;
 using gl::glBlendColorxOES;
 using gl::glBlendEquationEXT;
+using gl::glBlendEquationiARB;
 using gl::glBlendEquationIndexedAMD;
 using gl::glBlendEquationSeparateEXT;
-using gl::glBlendEquationSeparateIndexedAMD;
 using gl::glBlendEquationSeparateiARB;
-using gl::glBlendEquationiARB;
+using gl::glBlendEquationSeparateIndexedAMD;
+using gl::glBlendFunciARB;
 using gl::glBlendFuncIndexedAMD;
 using gl::glBlendFuncSeparateEXT;
-using gl::glBlendFuncSeparateINGR;
-using gl::glBlendFuncSeparateIndexedAMD;
 using gl::glBlendFuncSeparateiARB;
-using gl::glBlendFunciARB;
+using gl::glBlendFuncSeparateIndexedAMD;
+using gl::glBlendFuncSeparateINGR;
 using gl::glBlendParameteriNV;
 using gl::glBlitFramebufferEXT;
 using gl::glBufferAddressRangeNV;
+using gl::glBufferAttachMemoryNV;
 using gl::glBufferDataARB;
 using gl::glBufferPageCommitmentARB;
+using gl::glBufferPageCommitmentMemNV;
 using gl::glBufferParameteriAPPLE;
+using gl::glBufferStorageExternalEXT;
+using gl::glBufferStorageMemEXT;
 using gl::glBufferSubDataARB;
 using gl::glCallCommandListNV;
 using gl::glCheckFramebufferStatusEXT;
@@ -114,6 +127,7 @@ using gl::glClearNamedBufferSubDataEXT;
 using gl::glClientActiveTextureARB;
 using gl::glClientActiveVertexStreamATI;
 using gl::glClientAttribDefaultEXT;
+using gl::glClientWaitSemaphoreui64NVX;
 using gl::glClipPlanefOES;
 using gl::glClipPlanexOES;
 using gl::glColor3fVertex3fSUN;
@@ -219,17 +233,21 @@ using gl::glCopyTextureImage2DEXT;
 using gl::glCopyTextureSubImage1DEXT;
 using gl::glCopyTextureSubImage2DEXT;
 using gl::glCopyTextureSubImage3DEXT;
+using gl::glCoverageModulationNV;
+using gl::glCoverageModulationTableNV;
 using gl::glCoverFillPathInstancedNV;
 using gl::glCoverFillPathNV;
 using gl::glCoverStrokePathInstancedNV;
 using gl::glCoverStrokePathNV;
-using gl::glCoverageModulationNV;
-using gl::glCoverageModulationTableNV;
 using gl::glCreateCommandListsNV;
+using gl::glCreateMemoryObjectsEXT;
 using gl::glCreatePerfQueryINTEL;
 using gl::glCreateProgramObjectARB;
+using gl::glCreateProgressFenceNVX;
+using gl::glCreateSemaphoresNV;
 using gl::glCreateShaderObjectARB;
 using gl::glCreateShaderProgramEXT;
+using gl::glCreateShaderProgramvEXT;
 using gl::glCreateStatesNV;
 using gl::glCreateSyncFromCLeventARB;
 using gl::glCullParameterdvEXT;
@@ -237,13 +255,16 @@ using gl::glCullParameterfvEXT;
 using gl::glCurrentPaletteMatrixARB;
 using gl::glDebugMessageCallbackAMD;
 using gl::glDebugMessageCallbackARB;
+using gl::glDebugMessageCallbackKHR;
 using gl::glDebugMessageControlARB;
+using gl::glDebugMessageControlKHR;
 using gl::glDebugMessageEnableAMD;
 using gl::glDebugMessageInsertAMD;
 using gl::glDebugMessageInsertARB;
-using gl::glDeformSGIX;
+using gl::glDebugMessageInsertKHR;
 using gl::glDeformationMap3dSGIX;
 using gl::glDeformationMap3fSGIX;
+using gl::glDeformSGIX;
 using gl::glDeleteAsyncMarkersSGIX;
 using gl::glDeleteBuffersARB;
 using gl::glDeleteCommandListsNV;
@@ -251,6 +272,7 @@ using gl::glDeleteFencesAPPLE;
 using gl::glDeleteFencesNV;
 using gl::glDeleteFragmentShaderATI;
 using gl::glDeleteFramebuffersEXT;
+using gl::glDeleteMemoryObjectsEXT;
 using gl::glDeleteNamedStringARB;
 using gl::glDeleteNamesAMD;
 using gl::glDeleteObjectARB;
@@ -258,24 +280,29 @@ using gl::glDeleteOcclusionQueriesNV;
 using gl::glDeletePathsNV;
 using gl::glDeletePerfMonitorsAMD;
 using gl::glDeletePerfQueryINTEL;
+using gl::glDeleteProgramPipelinesEXT;
 using gl::glDeleteProgramsARB;
 using gl::glDeleteProgramsNV;
 using gl::glDeleteQueriesARB;
+using gl::glDeleteQueryResourceTagNV;
 using gl::glDeleteRenderbuffersEXT;
+using gl::glDeleteSemaphoresEXT;
 using gl::glDeleteStatesNV;
 using gl::glDeleteTexturesEXT;
 using gl::glDeleteTransformFeedbacksNV;
 using gl::glDeleteVertexArraysAPPLE;
 using gl::glDeleteVertexShaderEXT;
-using gl::glDepthBoundsEXT;
 using gl::glDepthBoundsdNV;
+using gl::glDepthBoundsEXT;
+using gl::glDepthRangeArraydvNV;
 using gl::glDepthRangedNV;
 using gl::glDepthRangefOES;
+using gl::glDepthRangeIndexeddNV;
 using gl::glDepthRangexOES;
 using gl::glDetachObjectARB;
 using gl::glDetailTexFuncSGIS;
-using gl::glDisableClientStateIndexedEXT;
 using gl::glDisableClientStateiEXT;
+using gl::glDisableClientStateIndexedEXT;
 using gl::glDisableIndexedEXT;
 using gl::glDisableVariantClientStateEXT;
 using gl::glDisableVertexArrayAttribEXT;
@@ -297,18 +324,23 @@ using gl::glDrawElementArrayATI;
 using gl::glDrawElementsInstancedARB;
 using gl::glDrawElementsInstancedEXT;
 using gl::glDrawMeshArraysSUN;
+using gl::glDrawMeshTasksIndirectNV;
+using gl::glDrawMeshTasksNV;
 using gl::glDrawRangeElementArrayAPPLE;
 using gl::glDrawRangeElementArrayATI;
 using gl::glDrawRangeElementsEXT;
 using gl::glDrawTextureNV;
 using gl::glDrawTransformFeedbackNV;
+using gl::glDrawVkImageNV;
 using gl::glEdgeFlagFormatNV;
 using gl::glEdgeFlagPointerEXT;
 using gl::glEdgeFlagPointerListIBM;
+using gl::glEGLImageTargetTexStorageEXT;
+using gl::glEGLImageTargetTextureStorageEXT;
 using gl::glElementPointerAPPLE;
 using gl::glElementPointerATI;
-using gl::glEnableClientStateIndexedEXT;
 using gl::glEnableClientStateiEXT;
+using gl::glEnableClientStateIndexedEXT;
 using gl::glEnableIndexedEXT;
 using gl::glEnableVariantClientStateEXT;
 using gl::glEnableVertexArrayAttribEXT;
@@ -348,40 +380,41 @@ using gl::glFlushRasterSGIX;
 using gl::glFlushStaticDataIBM;
 using gl::glFlushVertexArrayRangeAPPLE;
 using gl::glFlushVertexArrayRangeNV;
-using gl::glFogCoordFormatNV;
-using gl::glFogCoordPointerEXT;
-using gl::glFogCoordPointerListIBM;
 using gl::glFogCoorddEXT;
 using gl::glFogCoorddvEXT;
 using gl::glFogCoordfEXT;
+using gl::glFogCoordFormatNV;
 using gl::glFogCoordfvEXT;
 using gl::glFogCoordhNV;
 using gl::glFogCoordhvNV;
+using gl::glFogCoordPointerEXT;
+using gl::glFogCoordPointerListIBM;
 using gl::glFogFuncSGIS;
 using gl::glFogxOES;
 using gl::glFogxvOES;
 using gl::glFragmentColorMaterialSGIX;
 using gl::glFragmentCoverageColorNV;
-using gl::glFragmentLightModelfSGIX;
-using gl::glFragmentLightModelfvSGIX;
-using gl::glFragmentLightModeliSGIX;
-using gl::glFragmentLightModelivSGIX;
 using gl::glFragmentLightfSGIX;
 using gl::glFragmentLightfvSGIX;
 using gl::glFragmentLightiSGIX;
 using gl::glFragmentLightivSGIX;
+using gl::glFragmentLightModelfSGIX;
+using gl::glFragmentLightModelfvSGIX;
+using gl::glFragmentLightModeliSGIX;
+using gl::glFragmentLightModelivSGIX;
 using gl::glFragmentMaterialfSGIX;
 using gl::glFragmentMaterialfvSGIX;
 using gl::glFragmentMaterialiSGIX;
 using gl::glFragmentMaterialivSGIX;
-using gl::glFrameTerminatorGREMEDY;
-using gl::glFrameZoomSGIX;
 using gl::glFramebufferDrawBufferEXT;
 using gl::glFramebufferDrawBuffersEXT;
+using gl::glFramebufferFetchBarrierEXT;
+using gl::glFramebufferParameteriMESA;
 using gl::glFramebufferReadBufferEXT;
 using gl::glFramebufferRenderbufferEXT;
 using gl::glFramebufferSampleLocationsfvARB;
 using gl::glFramebufferSampleLocationsfvNV;
+using gl::glFramebufferSamplePositionsfvAMD;
 using gl::glFramebufferTexture1DEXT;
 using gl::glFramebufferTexture2DEXT;
 using gl::glFramebufferTexture3DEXT;
@@ -392,11 +425,16 @@ using gl::glFramebufferTextureFaceEXT;
 using gl::glFramebufferTextureLayerARB;
 using gl::glFramebufferTextureLayerEXT;
 using gl::glFramebufferTextureMultiviewOVR;
+using gl::glFrameTerminatorGREMEDY;
+using gl::glFrameZoomSGIX;
 using gl::glFreeObjectBufferATI;
 using gl::glFrustumfOES;
 using gl::glFrustumxOES;
 using gl::glGenAsyncMarkersSGIX;
 using gl::glGenBuffersARB;
+using gl::glGenerateMipmapEXT;
+using gl::glGenerateMultiTexMipmapEXT;
+using gl::glGenerateTextureMipmapEXT;
 using gl::glGenFencesAPPLE;
 using gl::glGenFencesNV;
 using gl::glGenFragmentShadersATI;
@@ -405,18 +443,18 @@ using gl::glGenNamesAMD;
 using gl::glGenOcclusionQueriesNV;
 using gl::glGenPathsNV;
 using gl::glGenPerfMonitorsAMD;
+using gl::glGenProgramPipelinesEXT;
 using gl::glGenProgramsARB;
 using gl::glGenProgramsNV;
 using gl::glGenQueriesARB;
+using gl::glGenQueryResourceTagNV;
 using gl::glGenRenderbuffersEXT;
+using gl::glGenSemaphoresEXT;
 using gl::glGenSymbolsEXT;
 using gl::glGenTexturesEXT;
 using gl::glGenTransformFeedbacksNV;
 using gl::glGenVertexArraysAPPLE;
 using gl::glGenVertexShadersEXT;
-using gl::glGenerateMipmapEXT;
-using gl::glGenerateMultiTexMipmapEXT;
-using gl::glGenerateTextureMipmapEXT;
 using gl::glGetActiveAttribARB;
 using gl::glGetActiveUniformARB;
 using gl::glGetActiveVaryingNV;
@@ -459,16 +497,17 @@ using gl::glGetConvolutionParameterxvOES;
 using gl::glGetCoverageModulationTableNV;
 using gl::glGetDebugMessageLogAMD;
 using gl::glGetDebugMessageLogARB;
+using gl::glGetDebugMessageLogKHR;
 using gl::glGetDetailTexFuncSGIS;
-using gl::glGetDoubleIndexedvEXT;
 using gl::glGetDoublei_vEXT;
+using gl::glGetDoubleIndexedvEXT;
 using gl::glGetFenceivNV;
 using gl::glGetFinalCombinerInputParameterfvNV;
 using gl::glGetFinalCombinerInputParameterivNV;
 using gl::glGetFirstPerfQueryIdINTEL;
 using gl::glGetFixedvOES;
-using gl::glGetFloatIndexedvEXT;
 using gl::glGetFloati_vEXT;
+using gl::glGetFloatIndexedvEXT;
 using gl::glGetFogFuncSGIS;
 using gl::glGetFragDataLocationEXT;
 using gl::glGetFragmentLightfvSGIX;
@@ -476,8 +515,11 @@ using gl::glGetFragmentLightivSGIX;
 using gl::glGetFragmentMaterialfvSGIX;
 using gl::glGetFragmentMaterialivSGIX;
 using gl::glGetFramebufferAttachmentParameterivEXT;
+using gl::glGetFramebufferParameterfvAMD;
 using gl::glGetFramebufferParameterivEXT;
+using gl::glGetFramebufferParameterivMESA;
 using gl::glGetGraphicsResetStatusARB;
+using gl::glGetGraphicsResetStatusKHR;
 using gl::glGetHandleARB;
 using gl::glGetHistogram;
 using gl::glGetHistogramEXT;
@@ -500,6 +542,7 @@ using gl::glGetInvariantBooleanvEXT;
 using gl::glGetInvariantFloatvEXT;
 using gl::glGetInvariantIntegervEXT;
 using gl::glGetLightxOES;
+using gl::glGetLightxvOES;
 using gl::glGetListParameterfvSGIX;
 using gl::glGetListParameterivSGIX;
 using gl::glGetLocalConstantBooleanvEXT;
@@ -512,12 +555,16 @@ using gl::glGetMapParameterfvNV;
 using gl::glGetMapParameterivNV;
 using gl::glGetMapxvOES;
 using gl::glGetMaterialxOES;
+using gl::glGetMaterialxvOES;
+using gl::glGetMemoryObjectDetachedResourcesuivNV;
+using gl::glGetMemoryObjectParameterivEXT;
 using gl::glGetMinmax;
 using gl::glGetMinmaxEXT;
 using gl::glGetMinmaxParameterfv;
 using gl::glGetMinmaxParameterfvEXT;
 using gl::glGetMinmaxParameteriv;
 using gl::glGetMinmaxParameterivEXT;
+using gl::glGetMultisamplefvNV;
 using gl::glGetMultiTexEnvfvEXT;
 using gl::glGetMultiTexEnvivEXT;
 using gl::glGetMultiTexGendvEXT;
@@ -526,33 +573,58 @@ using gl::glGetMultiTexGenivEXT;
 using gl::glGetMultiTexImageEXT;
 using gl::glGetMultiTexLevelParameterfvEXT;
 using gl::glGetMultiTexLevelParameterivEXT;
+using gl::glGetMultiTexParameterfvEXT;
 using gl::glGetMultiTexParameterIivEXT;
 using gl::glGetMultiTexParameterIuivEXT;
-using gl::glGetMultiTexParameterfvEXT;
 using gl::glGetMultiTexParameterivEXT;
-using gl::glGetMultisamplefvNV;
 using gl::glGetNamedBufferParameterivEXT;
 using gl::glGetNamedBufferParameterui64vNV;
 using gl::glGetNamedBufferPointervEXT;
 using gl::glGetNamedBufferSubDataEXT;
 using gl::glGetNamedFramebufferAttachmentParameterivEXT;
+using gl::glGetNamedFramebufferParameterfvAMD;
 using gl::glGetNamedFramebufferParameterivEXT;
-using gl::glGetNamedProgramLocalParameterIivEXT;
-using gl::glGetNamedProgramLocalParameterIuivEXT;
+using gl::glGetNamedProgramivEXT;
 using gl::glGetNamedProgramLocalParameterdvEXT;
 using gl::glGetNamedProgramLocalParameterfvEXT;
+using gl::glGetNamedProgramLocalParameterIivEXT;
+using gl::glGetNamedProgramLocalParameterIuivEXT;
 using gl::glGetNamedProgramStringEXT;
-using gl::glGetNamedProgramivEXT;
 using gl::glGetNamedRenderbufferParameterivEXT;
 using gl::glGetNamedStringARB;
 using gl::glGetNamedStringivARB;
+using gl::glGetnColorTableARB;
+using gl::glGetnCompressedTexImageARB;
+using gl::glGetnConvolutionFilterARB;
 using gl::glGetNextPerfQueryIdINTEL;
+using gl::glGetnHistogramARB;
+using gl::glGetnMapdvARB;
+using gl::glGetnMapfvARB;
+using gl::glGetnMapivARB;
+using gl::glGetnMinmaxARB;
+using gl::glGetnPixelMapfvARB;
+using gl::glGetnPixelMapuivARB;
+using gl::glGetnPixelMapusvARB;
+using gl::glGetnPolygonStippleARB;
+using gl::glGetnSeparableFilterARB;
+using gl::glGetnTexImageARB;
+using gl::glGetnUniformdvARB;
+using gl::glGetnUniformfvARB;
+using gl::glGetnUniformfvKHR;
+using gl::glGetnUniformi64vARB;
+using gl::glGetnUniformivARB;
+using gl::glGetnUniformivKHR;
+using gl::glGetnUniformui64vARB;
+using gl::glGetnUniformuivARB;
+using gl::glGetnUniformuivKHR;
 using gl::glGetObjectBufferfvATI;
 using gl::glGetObjectBufferivATI;
 using gl::glGetObjectLabelEXT;
+using gl::glGetObjectLabelKHR;
 using gl::glGetObjectParameterfvARB;
 using gl::glGetObjectParameterivAPPLE;
 using gl::glGetObjectParameterivARB;
+using gl::glGetObjectPtrLabelKHR;
 using gl::glGetOcclusionQueryivNV;
 using gl::glGetOcclusionQueryuivNV;
 using gl::glGetPathColorGenfvNV;
@@ -571,10 +643,10 @@ using gl::glGetPathTexGenivNV;
 using gl::glGetPerfCounterInfoINTEL;
 using gl::glGetPerfMonitorCounterDataAMD;
 using gl::glGetPerfMonitorCounterInfoAMD;
-using gl::glGetPerfMonitorCounterStringAMD;
 using gl::glGetPerfMonitorCountersAMD;
-using gl::glGetPerfMonitorGroupStringAMD;
+using gl::glGetPerfMonitorCounterStringAMD;
 using gl::glGetPerfMonitorGroupsAMD;
+using gl::glGetPerfMonitorGroupStringAMD;
 using gl::glGetPerfQueryDataINTEL;
 using gl::glGetPerfQueryIdByNameINTEL;
 using gl::glGetPerfQueryInfoINTEL;
@@ -583,36 +655,43 @@ using gl::glGetPixelTexGenParameterfvSGIS;
 using gl::glGetPixelTexGenParameterivSGIS;
 using gl::glGetPixelTransformParameterfvEXT;
 using gl::glGetPixelTransformParameterivEXT;
-using gl::glGetPointerIndexedvEXT;
 using gl::glGetPointeri_vEXT;
+using gl::glGetPointerIndexedvEXT;
 using gl::glGetPointervEXT;
-using gl::glGetProgramEnvParameterIivNV;
-using gl::glGetProgramEnvParameterIuivNV;
+using gl::glGetPointervKHR;
 using gl::glGetProgramEnvParameterdvARB;
 using gl::glGetProgramEnvParameterfvARB;
-using gl::glGetProgramLocalParameterIivNV;
-using gl::glGetProgramLocalParameterIuivNV;
+using gl::glGetProgramEnvParameterIivNV;
+using gl::glGetProgramEnvParameterIuivNV;
+using gl::glGetProgramivARB;
+using gl::glGetProgramivNV;
 using gl::glGetProgramLocalParameterdvARB;
 using gl::glGetProgramLocalParameterfvARB;
+using gl::glGetProgramLocalParameterIivNV;
+using gl::glGetProgramLocalParameterIuivNV;
 using gl::glGetProgramNamedParameterdvNV;
 using gl::glGetProgramNamedParameterfvNV;
 using gl::glGetProgramParameterdvNV;
 using gl::glGetProgramParameterfvNV;
+using gl::glGetProgramPipelineInfoLogEXT;
+using gl::glGetProgramPipelineivEXT;
 using gl::glGetProgramResourcefvNV;
 using gl::glGetProgramStringARB;
 using gl::glGetProgramStringNV;
 using gl::glGetProgramSubroutineParameteruivNV;
-using gl::glGetProgramivARB;
-using gl::glGetProgramivNV;
+using gl::glGetQueryivARB;
 using gl::glGetQueryObjecti64vEXT;
 using gl::glGetQueryObjectivARB;
 using gl::glGetQueryObjectui64vEXT;
 using gl::glGetQueryObjectuivARB;
-using gl::glGetQueryivARB;
 using gl::glGetRenderbufferParameterivEXT;
+using gl::glGetSemaphoreParameterivNV;
+using gl::glGetSemaphoreParameterui64vEXT;
 using gl::glGetSeparableFilter;
 using gl::glGetSeparableFilterEXT;
 using gl::glGetShaderSourceARB;
+using gl::glGetShadingRateImagePaletteNV;
+using gl::glGetShadingRateSampleLocationivNV;
 using gl::glGetSharpenTexFuncSGIS;
 using gl::glGetStageIndexNV;
 using gl::glGetTexBumpParameterfvATI;
@@ -630,9 +709,9 @@ using gl::glGetTextureHandleNV;
 using gl::glGetTextureImageEXT;
 using gl::glGetTextureLevelParameterfvEXT;
 using gl::glGetTextureLevelParameterivEXT;
+using gl::glGetTextureParameterfvEXT;
 using gl::glGetTextureParameterIivEXT;
 using gl::glGetTextureParameterIuivEXT;
-using gl::glGetTextureParameterfvEXT;
 using gl::glGetTextureParameterivEXT;
 using gl::glGetTextureSamplerHandleARB;
 using gl::glGetTextureSamplerHandleNV;
@@ -640,15 +719,17 @@ using gl::glGetTrackMatrixivNV;
 using gl::glGetTransformFeedbackVaryingEXT;
 using gl::glGetTransformFeedbackVaryingNV;
 using gl::glGetUniformBufferSizeEXT;
-using gl::glGetUniformLocationARB;
-using gl::glGetUniformOffsetEXT;
 using gl::glGetUniformfvARB;
 using gl::glGetUniformi64vARB;
 using gl::glGetUniformi64vNV;
 using gl::glGetUniformivARB;
+using gl::glGetUniformLocationARB;
+using gl::glGetUniformOffsetEXT;
 using gl::glGetUniformui64vARB;
 using gl::glGetUniformui64vNV;
 using gl::glGetUniformuivEXT;
+using gl::glGetUnsignedBytei_vEXT;
+using gl::glGetUnsignedBytevEXT;
 using gl::glGetVariantArrayObjectfvATI;
 using gl::glGetVariantArrayObjectivATI;
 using gl::glGetVariantBooleanvEXT;
@@ -662,48 +743,29 @@ using gl::glGetVertexArrayPointeri_vEXT;
 using gl::glGetVertexArrayPointervEXT;
 using gl::glGetVertexAttribArrayObjectfvATI;
 using gl::glGetVertexAttribArrayObjectivATI;
+using gl::glGetVertexAttribdvARB;
+using gl::glGetVertexAttribdvNV;
+using gl::glGetVertexAttribfvARB;
+using gl::glGetVertexAttribfvNV;
 using gl::glGetVertexAttribIivEXT;
 using gl::glGetVertexAttribIuivEXT;
+using gl::glGetVertexAttribivARB;
+using gl::glGetVertexAttribivNV;
 using gl::glGetVertexAttribLdvEXT;
 using gl::glGetVertexAttribLi64vNV;
 using gl::glGetVertexAttribLui64vARB;
 using gl::glGetVertexAttribLui64vNV;
 using gl::glGetVertexAttribPointervARB;
 using gl::glGetVertexAttribPointervNV;
-using gl::glGetVertexAttribdvARB;
-using gl::glGetVertexAttribdvNV;
-using gl::glGetVertexAttribfvARB;
-using gl::glGetVertexAttribfvNV;
-using gl::glGetVertexAttribivARB;
-using gl::glGetVertexAttribivNV;
+using gl::glGetVideoCaptureivNV;
 using gl::glGetVideoCaptureStreamdvNV;
 using gl::glGetVideoCaptureStreamfvNV;
 using gl::glGetVideoCaptureStreamivNV;
-using gl::glGetVideoCaptureivNV;
 using gl::glGetVideoi64vNV;
 using gl::glGetVideoivNV;
 using gl::glGetVideoui64vNV;
 using gl::glGetVideouivNV;
-using gl::glGetnColorTableARB;
-using gl::glGetnCompressedTexImageARB;
-using gl::glGetnConvolutionFilterARB;
-using gl::glGetnHistogramARB;
-using gl::glGetnMapdvARB;
-using gl::glGetnMapfvARB;
-using gl::glGetnMapivARB;
-using gl::glGetnMinmaxARB;
-using gl::glGetnPixelMapfvARB;
-using gl::glGetnPixelMapuivARB;
-using gl::glGetnPixelMapusvARB;
-using gl::glGetnPolygonStippleARB;
-using gl::glGetnSeparableFilterARB;
-using gl::glGetnTexImageARB;
-using gl::glGetnUniformdvARB;
-using gl::glGetnUniformfvARB;
-using gl::glGetnUniformi64vARB;
-using gl::glGetnUniformivARB;
-using gl::glGetnUniformui64vARB;
-using gl::glGetnUniformuivARB;
+using gl::glGetVkProcAddrNV;
 using gl::glGlobalAlphaFactorbSUN;
 using gl::glGlobalAlphaFactordSUN;
 using gl::glGlobalAlphaFactorfSUN;
@@ -720,6 +782,12 @@ using gl::glImageTransformParameterfHP;
 using gl::glImageTransformParameterfvHP;
 using gl::glImageTransformParameteriHP;
 using gl::glImageTransformParameterivHP;
+using gl::glImportMemoryFdEXT;
+using gl::glImportMemoryWin32HandleEXT;
+using gl::glImportMemoryWin32NameEXT;
+using gl::glImportSemaphoreFdEXT;
+using gl::glImportSemaphoreWin32HandleEXT;
+using gl::glImportSemaphoreWin32NameEXT;
 using gl::glImportSyncEXT;
 using gl::glIndexFormatNV;
 using gl::glIndexFuncEXT;
@@ -742,6 +810,7 @@ using gl::glIsFenceNV;
 using gl::glIsFramebufferEXT;
 using gl::glIsImageHandleResidentARB;
 using gl::glIsImageHandleResidentNV;
+using gl::glIsMemoryObjectEXT;
 using gl::glIsNameAMD;
 using gl::glIsNamedBufferResidentNV;
 using gl::glIsNamedStringARB;
@@ -752,8 +821,10 @@ using gl::glIsPointInFillPathNV;
 using gl::glIsPointInStrokePathNV;
 using gl::glIsProgramARB;
 using gl::glIsProgramNV;
+using gl::glIsProgramPipelineEXT;
 using gl::glIsQueryARB;
 using gl::glIsRenderbufferEXT;
+using gl::glIsSemaphoreEXT;
 using gl::glIsStateNV;
 using gl::glIsTextureEXT;
 using gl::glIsTextureHandleResidentARB;
@@ -763,6 +834,9 @@ using gl::glIsVariantEnabledEXT;
 using gl::glIsVertexArrayAPPLE;
 using gl::glIsVertexAttribEnabledAPPLE;
 using gl::glLabelObjectEXT;
+using gl::glLGPUCopyImageSubDataNVX;
+using gl::glLGPUInterlockNVX;
+using gl::glLGPUNamedBufferSubDataNVX;
 using gl::glLightEnviSGIX;
 using gl::glLightModelxOES;
 using gl::glLightModelxvOES;
@@ -819,19 +893,19 @@ using gl::glMatrixIndexuivARB;
 using gl::glMatrixIndexusvARB;
 using gl::glMatrixLoad3x2fNV;
 using gl::glMatrixLoad3x3fNV;
+using gl::glMatrixLoaddEXT;
+using gl::glMatrixLoadfEXT;
 using gl::glMatrixLoadIdentityEXT;
 using gl::glMatrixLoadTranspose3x3fNV;
 using gl::glMatrixLoadTransposedEXT;
 using gl::glMatrixLoadTransposefEXT;
-using gl::glMatrixLoaddEXT;
-using gl::glMatrixLoadfEXT;
 using gl::glMatrixMult3x2fNV;
 using gl::glMatrixMult3x3fNV;
+using gl::glMatrixMultdEXT;
+using gl::glMatrixMultfEXT;
 using gl::glMatrixMultTranspose3x3fNV;
 using gl::glMatrixMultTransposedEXT;
 using gl::glMatrixMultTransposefEXT;
-using gl::glMatrixMultdEXT;
-using gl::glMatrixMultfEXT;
 using gl::glMatrixOrthoEXT;
 using gl::glMatrixPopEXT;
 using gl::glMatrixPushEXT;
@@ -842,25 +916,41 @@ using gl::glMatrixScalefEXT;
 using gl::glMatrixTranslatedEXT;
 using gl::glMatrixTranslatefEXT;
 using gl::glMaxShaderCompilerThreadsARB;
+using gl::glMaxShaderCompilerThreadsKHR;
 using gl::glMemoryBarrierEXT;
-using gl::glMinSampleShadingARB;
+using gl::glMemoryObjectParameterivEXT;
 using gl::glMinmax;
 using gl::glMinmaxEXT;
-using gl::glMultMatrixxOES;
-using gl::glMultTransposeMatrixdARB;
-using gl::glMultTransposeMatrixfARB;
-using gl::glMultTransposeMatrixxOES;
+using gl::glMinSampleShadingARB;
+using gl::glMulticastBarrierNV;
+using gl::glMulticastBlitFramebufferNV;
+using gl::glMulticastBufferSubDataNV;
+using gl::glMulticastCopyBufferSubDataNV;
+using gl::glMulticastCopyImageSubDataNV;
+using gl::glMulticastFramebufferSampleLocationsfvNV;
+using gl::glMulticastGetQueryObjecti64vNV;
+using gl::glMulticastGetQueryObjectivNV;
+using gl::glMulticastGetQueryObjectui64vNV;
+using gl::glMulticastGetQueryObjectuivNV;
+using gl::glMulticastScissorArrayvNVX;
+using gl::glMulticastViewportArrayvNVX;
+using gl::glMulticastViewportPositionWScaleNVX;
+using gl::glMulticastWaitSyncNV;
 using gl::glMultiDrawArraysEXT;
 using gl::glMultiDrawArraysIndirectAMD;
 using gl::glMultiDrawArraysIndirectBindlessCountNV;
 using gl::glMultiDrawArraysIndirectBindlessNV;
+using gl::glMultiDrawArraysIndirectCount;
 using gl::glMultiDrawArraysIndirectCountARB;
 using gl::glMultiDrawElementArrayAPPLE;
 using gl::glMultiDrawElementsEXT;
 using gl::glMultiDrawElementsIndirectAMD;
 using gl::glMultiDrawElementsIndirectBindlessCountNV;
 using gl::glMultiDrawElementsIndirectBindlessNV;
+using gl::glMultiDrawElementsIndirectCount;
 using gl::glMultiDrawElementsIndirectCountARB;
+using gl::glMultiDrawMeshTasksIndirectCountNV;
+using gl::glMultiDrawMeshTasksIndirectNV;
 using gl::glMultiDrawRangeElementArrayAPPLE;
 using gl::glMultiModeDrawArraysIBM;
 using gl::glMultiModeDrawElementsIBM;
@@ -935,26 +1025,35 @@ using gl::glMultiTexGenivEXT;
 using gl::glMultiTexImage1DEXT;
 using gl::glMultiTexImage2DEXT;
 using gl::glMultiTexImage3DEXT;
-using gl::glMultiTexParameterIivEXT;
-using gl::glMultiTexParameterIuivEXT;
 using gl::glMultiTexParameterfEXT;
 using gl::glMultiTexParameterfvEXT;
 using gl::glMultiTexParameteriEXT;
+using gl::glMultiTexParameterIivEXT;
+using gl::glMultiTexParameterIuivEXT;
 using gl::glMultiTexParameterivEXT;
 using gl::glMultiTexRenderbufferEXT;
 using gl::glMultiTexSubImage1DEXT;
 using gl::glMultiTexSubImage2DEXT;
 using gl::glMultiTexSubImage3DEXT;
+using gl::glMultMatrixxOES;
+using gl::glMultTransposeMatrixdARB;
+using gl::glMultTransposeMatrixfARB;
+using gl::glMultTransposeMatrixxOES;
+using gl::glNamedBufferAttachMemoryNV;
 using gl::glNamedBufferDataEXT;
 using gl::glNamedBufferPageCommitmentARB;
 using gl::glNamedBufferPageCommitmentEXT;
+using gl::glNamedBufferPageCommitmentMemNV;
 using gl::glNamedBufferStorageEXT;
+using gl::glNamedBufferStorageExternalEXT;
+using gl::glNamedBufferStorageMemEXT;
 using gl::glNamedBufferSubDataEXT;
 using gl::glNamedCopyBufferSubDataEXT;
 using gl::glNamedFramebufferParameteriEXT;
 using gl::glNamedFramebufferRenderbufferEXT;
 using gl::glNamedFramebufferSampleLocationsfvARB;
 using gl::glNamedFramebufferSampleLocationsfvNV;
+using gl::glNamedFramebufferSamplePositionsfvAMD;
 using gl::glNamedFramebufferTexture1DEXT;
 using gl::glNamedFramebufferTexture2DEXT;
 using gl::glNamedFramebufferTexture3DEXT;
@@ -974,6 +1073,7 @@ using gl::glNamedProgramLocalParametersI4ivEXT;
 using gl::glNamedProgramLocalParametersI4uivEXT;
 using gl::glNamedProgramStringEXT;
 using gl::glNamedRenderbufferStorageEXT;
+using gl::glNamedRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glNamedRenderbufferStorageMultisampleCoverageEXT;
 using gl::glNamedRenderbufferStorageMultisampleEXT;
 using gl::glNamedStringARB;
@@ -998,12 +1098,12 @@ using gl::glNormalStream3iATI;
 using gl::glNormalStream3ivATI;
 using gl::glNormalStream3sATI;
 using gl::glNormalStream3svATI;
+using gl::glObjectLabelKHR;
+using gl::glObjectPtrLabelKHR;
 using gl::glObjectPurgeableAPPLE;
 using gl::glObjectUnpurgeableAPPLE;
 using gl::glOrthofOES;
 using gl::glOrthoxOES;
-using gl::glPNTrianglesfATI;
-using gl::glPNTrianglesiATI;
 using gl::glPassTexCoordATI;
 using gl::glPassThroughxOES;
 using gl::glPathColorGenNV;
@@ -1042,6 +1142,8 @@ using gl::glPixelTransformParameterfvEXT;
 using gl::glPixelTransformParameteriEXT;
 using gl::glPixelTransformParameterivEXT;
 using gl::glPixelZoomxOES;
+using gl::glPNTrianglesfATI;
+using gl::glPNTrianglesiATI;
 using gl::glPointAlongPathNV;
 using gl::glPointParameterfARB;
 using gl::glPointParameterfEXT;
@@ -1051,13 +1153,16 @@ using gl::glPointParameterfvEXT;
 using gl::glPointParameterfvSGIS;
 using gl::glPointParameteriNV;
 using gl::glPointParameterivNV;
+using gl::glPointParameterxOES;
 using gl::glPointParameterxvOES;
 using gl::glPointSizexOES;
 using gl::glPollAsyncSGIX;
 using gl::glPollInstrumentsSGIX;
+using gl::glPolygonOffsetClamp;
 using gl::glPolygonOffsetClampEXT;
 using gl::glPolygonOffsetEXT;
 using gl::glPolygonOffsetxOES;
+using gl::glPopDebugGroupKHR;
 using gl::glPopGroupMarkerEXT;
 using gl::glPresentFrameDualFillNV;
 using gl::glPresentFrameKeyedNV;
@@ -1066,9 +1171,9 @@ using gl::glPrimitiveRestartIndexNV;
 using gl::glPrimitiveRestartNV;
 using gl::glPrioritizeTexturesEXT;
 using gl::glPrioritizeTexturesxOES;
+using gl::glProgramBufferParametersfvNV;
 using gl::glProgramBufferParametersIivNV;
 using gl::glProgramBufferParametersIuivNV;
-using gl::glProgramBufferParametersfvNV;
 using gl::glProgramEnvParameter4dARB;
 using gl::glProgramEnvParameter4dvARB;
 using gl::glProgramEnvParameter4fARB;
@@ -1197,9 +1302,12 @@ using gl::glProgramUniformui64vNV;
 using gl::glProgramVertexLimitNV;
 using gl::glProvokingVertexEXT;
 using gl::glPushClientAttribDefaultEXT;
+using gl::glPushDebugGroupKHR;
 using gl::glPushGroupMarkerEXT;
 using gl::glQueryMatrixxOES;
 using gl::glQueryObjectParameteruiAMD;
+using gl::glQueryResourceNV;
+using gl::glQueryResourceTagNV;
 using gl::glRasterPos2xOES;
 using gl::glRasterPos2xvOES;
 using gl::glRasterPos3xOES;
@@ -1209,12 +1317,16 @@ using gl::glRasterPos4xvOES;
 using gl::glRasterSamplesEXT;
 using gl::glReadInstrumentsSGIX;
 using gl::glReadnPixelsARB;
+using gl::glReadnPixelsKHR;
 using gl::glRectxOES;
 using gl::glRectxvOES;
 using gl::glReferencePlaneSGIX;
+using gl::glReleaseKeyedMutexWin32EXT;
 using gl::glRenderbufferStorageEXT;
+using gl::glRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glRenderbufferStorageMultisampleCoverageNV;
 using gl::glRenderbufferStorageMultisampleEXT;
+using gl::glRenderGpuMaskNV;
 using gl::glReplacementCodePointerSUN;
 using gl::glReplacementCodeubSUN;
 using gl::glReplacementCodeubvSUN;
@@ -1241,6 +1353,7 @@ using gl::glReplacementCodeusvSUN;
 using gl::glRequestResidentProgramsNV;
 using gl::glResetHistogram;
 using gl::glResetHistogramEXT;
+using gl::glResetMemoryObjectParameterNV;
 using gl::glResetMinmax;
 using gl::glResetMinmaxEXT;
 using gl::glResizeBuffersMESA;
@@ -1248,6 +1361,7 @@ using gl::glResolveDepthValuesNV;
 using gl::glResumeTransformFeedbackNV;
 using gl::glRotatexOES;
 using gl::glSampleCoverageARB;
+using gl::glSampleCoveragexOES;
 using gl::glSampleMapATI;
 using gl::glSampleMaskEXT;
 using gl::glSampleMaskIndexedNV;
@@ -1255,6 +1369,8 @@ using gl::glSampleMaskSGIS;
 using gl::glSamplePatternEXT;
 using gl::glSamplePatternSGIS;
 using gl::glScalexOES;
+using gl::glScissorExclusiveArrayvNV;
+using gl::glScissorExclusiveNV;
 using gl::glSecondaryColor3bEXT;
 using gl::glSecondaryColor3bvEXT;
 using gl::glSecondaryColor3dEXT;
@@ -1277,6 +1393,8 @@ using gl::glSecondaryColorFormatNV;
 using gl::glSecondaryColorPointerEXT;
 using gl::glSecondaryColorPointerListIBM;
 using gl::glSelectPerfMonitorCountersAMD;
+using gl::glSemaphoreParameterivNV;
+using gl::glSemaphoreParameterui64vEXT;
 using gl::glSeparableFilter2D;
 using gl::glSeparableFilter2DEXT;
 using gl::glSetFenceAPPLE;
@@ -1289,7 +1407,17 @@ using gl::glShaderOp1EXT;
 using gl::glShaderOp2EXT;
 using gl::glShaderOp3EXT;
 using gl::glShaderSourceARB;
+using gl::glShadingRateImageBarrierNV;
+using gl::glShadingRateImagePaletteNV;
+using gl::glShadingRateSampleOrderCustomNV;
+using gl::glShadingRateSampleOrderNV;
 using gl::glSharpenTexFuncSGIS;
+using gl::glSignalSemaphoreEXT;
+using gl::glSignalSemaphoreui64NVX;
+using gl::glSignalVkFenceNV;
+using gl::glSignalVkSemaphoreNV;
+using gl::glSpecializeShader;
+using gl::glSpecializeShaderARB;
 using gl::glSpriteParameterfSGIX;
 using gl::glSpriteParameterfvSGIX;
 using gl::glSpriteParameteriSGIX;
@@ -1331,6 +1459,7 @@ using gl::glTessellationModeAMD;
 using gl::glTestFenceAPPLE;
 using gl::glTestFenceNV;
 using gl::glTestObjectAPPLE;
+using gl::glTexAttachMemoryNV;
 using gl::glTexBufferARB;
 using gl::glTexBufferEXT;
 using gl::glTexBumpParameterfvATI;
@@ -1387,16 +1516,26 @@ using gl::glTexImage3DEXT;
 using gl::glTexImage3DMultisampleCoverageNV;
 using gl::glTexImage4DSGIS;
 using gl::glTexPageCommitmentARB;
+using gl::glTexPageCommitmentMemNV;
 using gl::glTexParameterIivEXT;
 using gl::glTexParameterIuivEXT;
 using gl::glTexParameterxOES;
 using gl::glTexParameterxvOES;
 using gl::glTexRenderbufferNV;
+using gl::glTexStorage1DEXT;
+using gl::glTexStorage2DEXT;
+using gl::glTexStorage3DEXT;
+using gl::glTexStorageMem1DEXT;
+using gl::glTexStorageMem2DEXT;
+using gl::glTexStorageMem2DMultisampleEXT;
+using gl::glTexStorageMem3DEXT;
+using gl::glTexStorageMem3DMultisampleEXT;
 using gl::glTexStorageSparseAMD;
 using gl::glTexSubImage1DEXT;
 using gl::glTexSubImage2DEXT;
 using gl::glTexSubImage3DEXT;
 using gl::glTexSubImage4DSGIS;
+using gl::glTextureAttachMemoryNV;
 using gl::glTextureBarrierNV;
 using gl::glTextureBufferEXT;
 using gl::glTextureBufferRangeEXT;
@@ -1412,11 +1551,12 @@ using gl::glTextureLightEXT;
 using gl::glTextureMaterialEXT;
 using gl::glTextureNormalEXT;
 using gl::glTexturePageCommitmentEXT;
-using gl::glTextureParameterIivEXT;
-using gl::glTextureParameterIuivEXT;
+using gl::glTexturePageCommitmentMemNV;
 using gl::glTextureParameterfEXT;
 using gl::glTextureParameterfvEXT;
 using gl::glTextureParameteriEXT;
+using gl::glTextureParameterIivEXT;
+using gl::glTextureParameterIuivEXT;
 using gl::glTextureParameterivEXT;
 using gl::glTextureRangeAPPLE;
 using gl::glTextureRenderbufferEXT;
@@ -1425,6 +1565,11 @@ using gl::glTextureStorage2DEXT;
 using gl::glTextureStorage2DMultisampleEXT;
 using gl::glTextureStorage3DEXT;
 using gl::glTextureStorage3DMultisampleEXT;
+using gl::glTextureStorageMem1DEXT;
+using gl::glTextureStorageMem2DEXT;
+using gl::glTextureStorageMem2DMultisampleEXT;
+using gl::glTextureStorageMem3DEXT;
+using gl::glTextureStorageMem3DMultisampleEXT;
 using gl::glTextureStorageSparseAMD;
 using gl::glTextureSubImage1DEXT;
 using gl::glTextureSubImage2DEXT;
@@ -1508,8 +1653,22 @@ using gl::glUnmapNamedBufferEXT;
 using gl::glUnmapObjectBufferATI;
 using gl::glUnmapTexture2DINTEL;
 using gl::glUpdateObjectBufferATI;
+using gl::glUploadGpuMaskNVX;
 using gl::glUseProgramObjectARB;
+using gl::glUseProgramStagesEXT;
 using gl::glUseShaderProgramEXT;
+using gl::glValidateProgramARB;
+using gl::glValidateProgramPipelineEXT;
+using gl::glVariantArrayObjectATI;
+using gl::glVariantbvEXT;
+using gl::glVariantdvEXT;
+using gl::glVariantfvEXT;
+using gl::glVariantivEXT;
+using gl::glVariantPointerEXT;
+using gl::glVariantsvEXT;
+using gl::glVariantubvEXT;
+using gl::glVariantuivEXT;
+using gl::glVariantusvEXT;
 using gl::glVDPAUFiniNV;
 using gl::glVDPAUGetSurfaceivNV;
 using gl::glVDPAUInitNV;
@@ -1517,20 +1676,10 @@ using gl::glVDPAUIsSurfaceNV;
 using gl::glVDPAUMapSurfacesNV;
 using gl::glVDPAURegisterOutputSurfaceNV;
 using gl::glVDPAURegisterVideoSurfaceNV;
+using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
 using gl::glVDPAUSurfaceAccessNV;
 using gl::glVDPAUUnmapSurfacesNV;
 using gl::glVDPAUUnregisterSurfaceNV;
-using gl::glValidateProgramARB;
-using gl::glVariantArrayObjectATI;
-using gl::glVariantPointerEXT;
-using gl::glVariantbvEXT;
-using gl::glVariantdvEXT;
-using gl::glVariantfvEXT;
-using gl::glVariantivEXT;
-using gl::glVariantsvEXT;
-using gl::glVariantubvEXT;
-using gl::glVariantuivEXT;
-using gl::glVariantusvEXT;
 using gl::glVertex2bOES;
 using gl::glVertex2bvOES;
 using gl::glVertex2hNV;
@@ -1613,13 +1762,6 @@ using gl::glVertexAttrib3sARB;
 using gl::glVertexAttrib3sNV;
 using gl::glVertexAttrib3svARB;
 using gl::glVertexAttrib3svNV;
-using gl::glVertexAttrib4NbvARB;
-using gl::glVertexAttrib4NivARB;
-using gl::glVertexAttrib4NsvARB;
-using gl::glVertexAttrib4NubARB;
-using gl::glVertexAttrib4NubvARB;
-using gl::glVertexAttrib4NuivARB;
-using gl::glVertexAttrib4NusvARB;
 using gl::glVertexAttrib4bvARB;
 using gl::glVertexAttrib4dARB;
 using gl::glVertexAttrib4dNV;
@@ -1632,6 +1774,13 @@ using gl::glVertexAttrib4fvNV;
 using gl::glVertexAttrib4hNV;
 using gl::glVertexAttrib4hvNV;
 using gl::glVertexAttrib4ivARB;
+using gl::glVertexAttrib4NbvARB;
+using gl::glVertexAttrib4NivARB;
+using gl::glVertexAttrib4NsvARB;
+using gl::glVertexAttrib4NubARB;
+using gl::glVertexAttrib4NubvARB;
+using gl::glVertexAttrib4NuivARB;
+using gl::glVertexAttrib4NusvARB;
 using gl::glVertexAttrib4sARB;
 using gl::glVertexAttrib4sNV;
 using gl::glVertexAttrib4svARB;
@@ -1753,23 +1902,26 @@ using gl::glVertexStream4iATI;
 using gl::glVertexStream4ivATI;
 using gl::glVertexStream4sATI;
 using gl::glVertexStream4svATI;
-using gl::glVertexWeightPointerEXT;
 using gl::glVertexWeightfEXT;
 using gl::glVertexWeightfvEXT;
 using gl::glVertexWeighthNV;
 using gl::glVertexWeighthvNV;
+using gl::glVertexWeightPointerEXT;
 using gl::glVideoCaptureNV;
 using gl::glVideoCaptureStreamParameterdvNV;
 using gl::glVideoCaptureStreamParameterfvNV;
 using gl::glVideoCaptureStreamParameterivNV;
 using gl::glViewportPositionWScaleNV;
 using gl::glViewportSwizzleNV;
-using gl::glWeightPathsNV;
-using gl::glWeightPointerARB;
+using gl::glWaitSemaphoreEXT;
+using gl::glWaitSemaphoreui64NVX;
+using gl::glWaitVkSemaphoreNV;
 using gl::glWeightbvARB;
 using gl::glWeightdvARB;
 using gl::glWeightfvARB;
 using gl::glWeightivARB;
+using gl::glWeightPathsNV;
+using gl::glWeightPointerARB;
 using gl::glWeightsvARB;
 using gl::glWeightubvARB;
 using gl::glWeightuivARB;
@@ -1817,5 +1969,4 @@ using gl::glWindowPos4svMESA;
 using gl::glWindowRectanglesEXT;
 using gl::glWriteMaskEXT;
 
-
-} // namespace gl45ext
+} // namespace gl45ext
\ No newline at end of file
