@@ -1,6 +1,7 @@
 
 #include "Binding_pch.h"
 
+
 using namespace gl;
 
 
@@ -21,10 +22,10 @@ Function<void, ClearBufferMask> Binding::Clear("glClear");
 Function<void, GLfloat, GLfloat, GLfloat, GLfloat> Binding::ClearAccum("glClearAccum");
 Function<void, GLfixed, GLfixed, GLfixed, GLfixed> Binding::ClearAccumxOES("glClearAccumxOES");
 Function<void, GLenum, GLenum, GLenum, GLenum, const void *> Binding::ClearBufferData("glClearBufferData");
-Function<void, GLenum, GLenum, GLintptr, GLsizeiptr, GLenum, GLenum, const void *> Binding::ClearBufferSubData("glClearBufferSubData");
 Function<void, GLenum, GLint, GLfloat, GLint> Binding::ClearBufferfi("glClearBufferfi");
 Function<void, GLenum, GLint, const GLfloat *> Binding::ClearBufferfv("glClearBufferfv");
 Function<void, GLenum, GLint, const GLint *> Binding::ClearBufferiv("glClearBufferiv");
+Function<void, GLenum, GLenum, GLintptr, GLsizeiptr, GLenum, GLenum, const void *> Binding::ClearBufferSubData("glClearBufferSubData");
 Function<void, GLenum, GLint, const GLuint *> Binding::ClearBufferuiv("glClearBufferuiv");
 Function<void, GLfloat, GLfloat, GLfloat, GLfloat> Binding::ClearColor("glClearColor");
 Function<void, GLint, GLint, GLint, GLint> Binding::ClearColorIiEXT("glClearColorIiEXT");
@@ -51,6 +52,7 @@ Function<void, GLenum> Binding::ClientActiveTexture("glClientActiveTexture");
 Function<void, GLenum> Binding::ClientActiveTextureARB("glClientActiveTextureARB");
 Function<void, GLenum> Binding::ClientActiveVertexStreamATI("glClientActiveVertexStreamATI");
 Function<void, ClientAttribMask> Binding::ClientAttribDefaultEXT("glClientAttribDefaultEXT");
+Function<void, GLsizei, const GLuint *, const GLuint64 *> Binding::ClientWaitSemaphoreui64NVX("glClientWaitSemaphoreui64NVX");
 Function<GLenum, GLsync, SyncObjectMask, GLuint64> Binding::ClientWaitSync("glClientWaitSync");
 Function<void, GLenum, GLenum> Binding::ClipControl("glClipControl");
 Function<void, GLenum, const GLdouble *> Binding::ClipPlane("glClipPlane");
@@ -61,9 +63,9 @@ Function<void, const GLbyte *> Binding::Color3bv("glColor3bv");
 Function<void, GLdouble, GLdouble, GLdouble> Binding::Color3d("glColor3d");
 Function<void, const GLdouble *> Binding::Color3dv("glColor3dv");
 Function<void, GLfloat, GLfloat, GLfloat> Binding::Color3f("glColor3f");
+Function<void, const GLfloat *> Binding::Color3fv("glColor3fv");
 Function<void, GLfloat, GLfloat, GLfloat, GLfloat, GLfloat, GLfloat> Binding::Color3fVertex3fSUN("glColor3fVertex3fSUN");
 Function<void, const GLfloat *, const GLfloat *> Binding::Color3fVertex3fvSUN("glColor3fVertex3fvSUN");
-Function<void, const GLfloat *> Binding::Color3fv("glColor3fv");
 Function<void, GLhalfNV, GLhalfNV, GLhalfNV> Binding::Color3hNV("glColor3hNV");
 Function<void, const GLhalfNV *> Binding::Color3hvNV("glColor3hvNV");
 Function<void, GLint, GLint, GLint> Binding::Color3i("glColor3i");
@@ -93,11 +95,11 @@ Function<void, const GLint *> Binding::Color4iv("glColor4iv");
 Function<void, GLshort, GLshort, GLshort, GLshort> Binding::Color4s("glColor4s");
 Function<void, const GLshort *> Binding::Color4sv("glColor4sv");
 Function<void, GLubyte, GLubyte, GLubyte, GLubyte> Binding::Color4ub("glColor4ub");
+Function<void, const GLubyte *> Binding::Color4ubv("glColor4ubv");
 Function<void, GLubyte, GLubyte, GLubyte, GLubyte, GLfloat, GLfloat> Binding::Color4ubVertex2fSUN("glColor4ubVertex2fSUN");
 Function<void, const GLubyte *, const GLfloat *> Binding::Color4ubVertex2fvSUN("glColor4ubVertex2fvSUN");
 Function<void, GLubyte, GLubyte, GLubyte, GLubyte, GLfloat, GLfloat, GLfloat> Binding::Color4ubVertex3fSUN("glColor4ubVertex3fSUN");
 Function<void, const GLubyte *, const GLfloat *> Binding::Color4ubVertex3fvSUN("glColor4ubVertex3fvSUN");
-Function<void, const GLubyte *> Binding::Color4ubv("glColor4ubv");
 Function<void, GLuint, GLuint, GLuint, GLuint> Binding::Color4ui("glColor4ui");
 Function<void, const GLuint *> Binding::Color4uiv("glColor4uiv");
 Function<void, GLushort, GLushort, GLushort, GLushort> Binding::Color4us("glColor4us");
@@ -105,12 +107,12 @@ Function<void, const GLushort *> Binding::Color4usv("glColor4usv");
 Function<void, GLfixed, GLfixed, GLfixed, GLfixed> Binding::Color4xOES("glColor4xOES");
 Function<void, const GLfixed *> Binding::Color4xvOES("glColor4xvOES");
 Function<void, GLint, GLenum, GLsizei> Binding::ColorFormatNV("glColorFormatNV");
-Function<void, GLenum, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint> Binding::ColorFragmentOp1ATI("glColorFragmentOp1ATI");
-Function<void, GLenum, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint> Binding::ColorFragmentOp2ATI("glColorFragmentOp2ATI");
-Function<void, GLenum, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint, GLuint> Binding::ColorFragmentOp3ATI("glColorFragmentOp3ATI");
+Function<void, GLenum, GLuint, FragmentShaderDestMaskATI, FragmentShaderDestModMaskATI, GLuint, GLuint, FragmentShaderColorModMaskATI> Binding::ColorFragmentOp1ATI("glColorFragmentOp1ATI");
+Function<void, GLenum, GLuint, FragmentShaderDestMaskATI, FragmentShaderDestModMaskATI, GLuint, GLuint, FragmentShaderColorModMaskATI, GLuint, GLuint, FragmentShaderColorModMaskATI> Binding::ColorFragmentOp2ATI("glColorFragmentOp2ATI");
+Function<void, GLenum, GLuint, FragmentShaderDestMaskATI, FragmentShaderDestModMaskATI, GLuint, GLuint, FragmentShaderColorModMaskATI, GLuint, GLuint, FragmentShaderColorModMaskATI, GLuint, GLuint, FragmentShaderColorModMaskATI> Binding::ColorFragmentOp3ATI("glColorFragmentOp3ATI");
 Function<void, GLboolean, GLboolean, GLboolean, GLboolean> Binding::ColorMask("glColorMask");
-Function<void, GLuint, GLboolean, GLboolean, GLboolean, GLboolean> Binding::ColorMaskIndexedEXT("glColorMaskIndexedEXT");
 Function<void, GLuint, GLboolean, GLboolean, GLboolean, GLboolean> Binding::ColorMaski("glColorMaski");
+Function<void, GLuint, GLboolean, GLboolean, GLboolean, GLboolean> Binding::ColorMaskIndexedEXT("glColorMaskIndexedEXT");
 Function<void, GLenum, GLenum> Binding::ColorMaterial("glColorMaterial");
 Function<void, GLenum, GLuint> Binding::ColorP3ui("glColorP3ui");
 Function<void, GLenum, const GLuint *> Binding::ColorP3uiv("glColorP3uiv");
@@ -221,28 +223,32 @@ Function<void, GLuint, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei> Bind
 Function<void, GLuint, GLenum, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei> Binding::CopyTextureSubImage2DEXT("glCopyTextureSubImage2DEXT");
 Function<void, GLuint, GLint, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei> Binding::CopyTextureSubImage3D("glCopyTextureSubImage3D");
 Function<void, GLuint, GLenum, GLint, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei> Binding::CopyTextureSubImage3DEXT("glCopyTextureSubImage3DEXT");
+Function<void, GLenum> Binding::CoverageModulationNV("glCoverageModulationNV");
+Function<void, GLsizei, const GLfloat *> Binding::CoverageModulationTableNV("glCoverageModulationTableNV");
 Function<void, GLsizei, GLenum, const void *, GLuint, GLenum, GLenum, const GLfloat *> Binding::CoverFillPathInstancedNV("glCoverFillPathInstancedNV");
 Function<void, GLuint, GLenum> Binding::CoverFillPathNV("glCoverFillPathNV");
 Function<void, GLsizei, GLenum, const void *, GLuint, GLenum, GLenum, const GLfloat *> Binding::CoverStrokePathInstancedNV("glCoverStrokePathInstancedNV");
 Function<void, GLuint, GLenum> Binding::CoverStrokePathNV("glCoverStrokePathNV");
-Function<void, GLenum> Binding::CoverageModulationNV("glCoverageModulationNV");
-Function<void, GLsizei, const GLfloat *> Binding::CoverageModulationTableNV("glCoverageModulationTableNV");
 Function<void, GLsizei, GLuint *> Binding::CreateBuffers("glCreateBuffers");
 Function<void, GLsizei, GLuint *> Binding::CreateCommandListsNV("glCreateCommandListsNV");
 Function<void, GLsizei, GLuint *> Binding::CreateFramebuffers("glCreateFramebuffers");
+Function<void, GLsizei, GLuint *> Binding::CreateMemoryObjectsEXT("glCreateMemoryObjectsEXT");
 Function<void, GLuint, GLuint *> Binding::CreatePerfQueryINTEL("glCreatePerfQueryINTEL");
 Function<GLuint> Binding::CreateProgram("glCreateProgram");
 Function<GLhandleARB> Binding::CreateProgramObjectARB("glCreateProgramObjectARB");
 Function<void, GLsizei, GLuint *> Binding::CreateProgramPipelines("glCreateProgramPipelines");
+Function<GLuint> Binding::CreateProgressFenceNVX("glCreateProgressFenceNVX");
 Function<void, GLenum, GLsizei, GLuint *> Binding::CreateQueries("glCreateQueries");
 Function<void, GLsizei, GLuint *> Binding::CreateRenderbuffers("glCreateRenderbuffers");
 Function<void, GLsizei, GLuint *> Binding::CreateSamplers("glCreateSamplers");
+Function<void, GLsizei, GLuint *> Binding::CreateSemaphoresNV("glCreateSemaphoresNV");
 Function<GLuint, GLenum> Binding::CreateShader("glCreateShader");
 Function<GLhandleARB, GLenum> Binding::CreateShaderObjectARB("glCreateShaderObjectARB");
 Function<GLuint, GLenum, const GLchar *> Binding::CreateShaderProgramEXT("glCreateShaderProgramEXT");
 Function<GLuint, GLenum, GLsizei, const GLchar *const*> Binding::CreateShaderProgramv("glCreateShaderProgramv");
+Function<GLuint, GLenum, GLsizei, const GLchar *const*> Binding::CreateShaderProgramvEXT("glCreateShaderProgramvEXT");
 Function<void, GLsizei, GLuint *> Binding::CreateStatesNV("glCreateStatesNV");
-Function<GLsync, _cl_context *, _cl_event *, UnusedMask> Binding::CreateSyncFromCLeventARB("glCreateSyncFromCLeventARB");
+Function<GLsync, _cl_context *, _cl_event *, GLbitfield> Binding::CreateSyncFromCLeventARB("glCreateSyncFromCLeventARB");
 Function<void, GLenum, GLsizei, GLuint *> Binding::CreateTextures("glCreateTextures");
 Function<void, GLsizei, GLuint *> Binding::CreateTransformFeedbacks("glCreateTransformFeedbacks");
 Function<void, GLsizei, GLuint *> Binding::CreateVertexArrays("glCreateVertexArrays");
@@ -252,4 +258,4 @@ Function<void, GLenum, GLfloat *> Binding::CullParameterfvEXT("glCullParameterfv
 Function<void, GLint> Binding::CurrentPaletteMatrixARB("glCurrentPaletteMatrixARB");
 
 
-} // namespace glbinding
+} // namespace glbinding
\ No newline at end of file
