@@ -1,6 +1,7 @@
 
 #include "Binding_pch.h"
 
+
 using namespace gl;
 
 
@@ -9,9 +10,9 @@ namespace glbinding
 
 
 Function<void, GLenum, GLenum> Binding::Hint("glHint");
-Function<void, GLenum, GLint> Binding::HintPGI("glHintPGI");
+Function<void, GLenum, VertexHintsMaskPGI> Binding::HintPGI("glHintPGI");
 Function<void, GLenum, GLsizei, GLenum, GLboolean> Binding::Histogram("glHistogram");
 Function<void, GLenum, GLsizei, GLenum, GLboolean> Binding::HistogramEXT("glHistogramEXT");
 
 
-} // namespace glbinding
+} // namespace glbinding
\ No newline at end of file
