@@ -1,11 +1,8 @@
 
 #include "../Binding_pch.h"
 
-
 #include <glbinding/gl/functions.h>
 
-using namespace glbinding;
-
 
 namespace gl
 {
@@ -13,24 +10,23 @@ namespace gl
 
 void glHint(GLenum target, GLenum mode)
 {
-    return Binding::Hint(target, mode);
+    return glbinding::Binding::Hint(target, mode);
 }
 
-void glHintPGI(GLenum target, GLint mode)
+void glHintPGI(GLenum target, VertexHintsMaskPGI mode)
 {
-    return Binding::HintPGI(target, mode);
+    return glbinding::Binding::HintPGI(target, mode);
 }
 
 void glHistogram(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)
 {
-    return Binding::Histogram(target, width, internalformat, sink);
+    return glbinding::Binding::Histogram(target, width, internalformat, sink);
 }
 
 void glHistogramEXT(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)
 {
-    return Binding::HistogramEXT(target, width, internalformat, sink);
+    return glbinding::Binding::HistogramEXT(target, width, internalformat, sink);
 }
 
 
-
-} // namespace gl
+} // namespace gl
\ No newline at end of file
