@@ -5,18 +5,20 @@
 #include <string>
 #include <type_traits>
 
-#define GLFW_INCLUDE_NONE
 #include <GLFW/glfw3.h>
 
-#include <glbinding/Meta.h>
-#include <glbinding/ContextInfo.h>
 #include <glbinding/Version.h>
-#include <glbinding/Binding.h>
+#include <glbinding/glbinding.h>
 
 #include <glbinding/gl/types.h>
 #include <glbinding/gl/enum.h>
 #include <glbinding/gl/functions.h>
 
+#include <glbinding-aux/Meta.h>
+#include <glbinding-aux/ContextInfo.h>
+#include <glbinding-aux/ValidVersions.h>
+#include <glbinding-aux/types_to_string.h>
+
 
 using namespace gl;
 using namespace glbinding;
@@ -167,15 +169,15 @@ namespace
         static const size_t MAX_PSTRING_LENGTH { 37 };    // actually, it's 44 / average is 23,
                                                           // but 37 works for 452 of 462 glGet enums (98%)
 
-        const std::string pstring{ glbinding::Meta::getString(pname) };
-        const std::string spaces{ std::string((glbinding::Meta::getString(pname).length() > 37) ? 0 : (MAX_PSTRING_LENGTH - pstring.length()), ' ') };
+        const std::string pstring{ glbinding::aux::Meta::getString(pname) };
+        const std::string spaces{ std::string((glbinding::aux::Meta::getString(pname).length() > 37) ? 0 : (MAX_PSTRING_LENGTH - pstring.length()), ' ') };
 
         if (glGetError() != gl::GL_NO_ERROR)
         {
             std::cout << "\t" << pstring << spaces << " = NOT AVAILABLE";
             return false;
         }
-        std::cout << "\t" << glbinding::Meta::getString(pname) << spaces << " = " << string<T, count>(data);
+        std::cout << "\t" << glbinding::aux::Meta::getString(pname) << spaces << " = " << string<T, count>(data);
         return true;
     }
 
@@ -187,7 +189,7 @@ namespace
         static const size_t MAX_PSTRING_LENGTH{ 37 };    // actually, it's 44 / average is 23,
         // but 37 works for 452 of 462 glGet enums (98%)
 
-        const std::string pstring{ glbinding::Meta::getString(pname) };
+        const std::string pstring{ glbinding::aux::Meta::getString(pname) };
         const std::string spaces{ std::string(MAX_PSTRING_LENGTH - pstring.length(), ' ') };
 
         if (glGetError() != gl::GL_NO_ERROR)
@@ -195,7 +197,7 @@ namespace
             std::cout << "\t" << pstring << spaces << " = NOT AVAILABLE";
             return false;
         }
-        std::cout << "\t" << glbinding::Meta::getString(pname) << spaces << " = " << string<T>(data, count);
+        std::cout << "\t" << glbinding::aux::Meta::getString(pname) << spaces << " = " << string<T>(data, count);
         return true;
     }
 
@@ -290,11 +292,11 @@ int main(int argc, const char * argv[])
     }
 #endif
 
+    glfwSetErrorCallback(error);
+
     if (!glfwInit())
         return 1;
 
-    glfwSetErrorCallback(error);
-
     glfwDefaultWindowHints();
     glfwWindowHint(GLFW_VISIBLE, false);
 
@@ -338,7 +340,7 @@ int main(int argc, const char * argv[])
 
     glfwMakeContextCurrent(window);
 
-    Binding::initialize();
+	glbinding::initialize(glfwGetProcAddress, false); // only resolve functions that are actually used (lazy)
 
     std::cout << std::endl << "[QUERYING STATE VALUES]" << std::endl;
 
@@ -852,7 +854,7 @@ int main(int argc, const char * argv[])
     requestState<GLint    , 1>(GL_SECONDARY_COLOR_ARRAY_STRIDE, { { 0 } });
     requestState<GLenum   , 1>(GL_SECONDARY_COLOR_ARRAY_TYPE, { { GL_FLOAT } });
 
-    std::cout << std::endl << "Stencil Seperate States" << std::endl;
+    std::cout << std::endl << "Stencil Separate States" << std::endl;
     requestState<GLenum   , 1>(GL_STENCIL_BACK_FAIL, { { GL_KEEP } });
     requestState<GLenum   , 1>(GL_STENCIL_BACK_FUNC, { { GL_ALWAYS } });
     requestState<GLenum   , 1>(GL_STENCIL_BACK_PASS_DEPTH_FAIL, { { GL_KEEP } });
@@ -932,12 +934,13 @@ int main(int argc, const char * argv[])
 
     std::cout << std::endl << std::endl << "[QUERYING STATE VALUES - UNGROUPED/TODO]" << std::endl;
 
+	// print some gl infos (query)
 
     std::cout << std::endl
-        << "OpenGL Version:  " << ContextInfo::version() << std::endl
-        << "OpenGL Vendor:   " << ContextInfo::vendor() << std::endl
-        << "OpenGL Renderer: " << ContextInfo::renderer() << std::endl
-        << "OpenGL Revision: " << Meta::glRevision() << " (gl.xml)" << std::endl << std::endl;
+        << "OpenGL Version:  " << aux::ContextInfo::version() << std::endl
+        << "OpenGL Vendor:   " << aux::ContextInfo::vendor() << std::endl
+        << "OpenGL Renderer: " << aux::ContextInfo::renderer() << std::endl
+        << "OpenGL Revision: " << aux::Meta::glRevision() << " (gl.xml)" << std::endl << std::endl;
 
     glfwTerminate();
     return 0;
